@@ -1,7 +1,5 @@
 import tifffile
 import warnings
-import nrrd
-
 import numpy as np
 
 
@@ -41,12 +39,13 @@ def to_tiff(img_volume, dest_path):
 
     :param np.ndarray img_volume: The image to be saved
     :param dest_path: Where to save the tiff stack
+    :return:
     """
     dest_path = str(dest_path)
     tifffile.imsave(dest_path, img_volume)
 
 
-def to_tiff_series(img_volume, path_prefix, path_suffix="", extension=".tif"):
+def to_tiffs(img_volume, path_prefix, path_suffix="", pad_width=4):
     """
     Save the image volume (numpy array) as a sequence of tiff planes.
     Each plane will have a filepath of the following for:
@@ -55,23 +54,19 @@ def to_tiff_series(img_volume, path_prefix, path_suffix="", extension=".tif"):
     :param np.ndarray img_volume: The image to be saved
     :param str path_prefix:  The prefix for each plane
     :param str path_suffix: The suffix for each plane
+    :param int pad_width: The number of digits on which the index of the
+        image (z plane number) will be padded
+    :return:
     """
-    z_size = img_volume.shape[0]
-    pad_width = int(round(z_size / 10)) + 1
+    z_size = img_volume.shape[-1]
+    if z_size > 10**pad_width:
+        raise ValueError(
+            "Not enough padding digits {} for value"
+            " {}".format(pad_width, z_size)
+        )
     for i in range(z_size):
-        img = img_volume[i, :, :]
-        dest_path = (
-            f"{path_prefix}_{str(i).zfill(pad_width)}{path_suffix}{extension}"
+        img = img_volume[:, :, i]
+        dest_path = "{}_{}{}.tif".format(
+            path_prefix, str(i).zfill(pad_width), path_suffix
         )
         tifffile.imsave(dest_path, img)
-
-
-def to_nrrd(img_volume, dest_path):
-    """
-    Saves the image volume (numpy array) as nrrd
-
-    :param np.ndarray img_volume: The image to be saved
-    :param dest_path: Where to save the nrrd image
-    """
-    dest_path = str(dest_path)
-    nrrd.write(dest_path, img_volume)
